OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "File consigliati",
    "Recently commented" : "Commentati di recente",
    "Recently edited" : "Modificati di recente",
    "Recently shared" : "Condivisi di recente",
    "Recommendations" : "Consigli",
    "Shows recommended files" : "Mostra i file consigliati",
    "Shows recommended files for quick access of files and folders with recent activity" : "Mostra i file consigliati per accedere rapidamente a file e cartelle con attività recente",
    "No recommendations yet" : "Ancora nessun consiglio",
    "Show recommendations" : "Mostra consigli"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
